import numpy as np
import matplotlib.pyplot as plt
import matplotlib as mpl

mpl.rcParams['lines.linewidth'] = 3
mpl.rcParams['legend.fontsize'] = 18
mpl.rcParams['xtick.labelsize'] = 12
mpl.rcParams['ytick.labelsize'] = 12
mpl.rcParams['axes.titlesize'] = 18
mpl.rcParams['axes.labelsize'] = 18

def cumulate(x):
    temp = x[0]
    for i in range(len(x)-1):
        x[i+1] = temp + x[i+1]
        temp = x[i+1]
    return x

transparency = 0.2

T = 20
plt.figure(figsize = (10,8))
n_repeat = 20
plt.xticks(np.arange(0,21,2))

nt = 200
for p in [16]:
    for alpha in [0, 0.5, 1,2,3]:
        label =r' $\lambda=$'+'%.1f'%alpha # r'$p=$'+str()+
        folder = 'UCB_case_study/n-200_T-20_p-'+str(p)+'_alpha-'+'%.1f'%alpha+'/'
        Regret = []
        for i in range(n_repeat):
            regret = np.loadtxt(folder + str(i)+'_regret.txt')
            regret = cumulate(regret)
            Regret.append(regret)

    
        mean = np.mean(Regret, axis = 0)/nt
        std = np.std(Regret, axis = 0)/nt
        plt.plot(np.arange(T)+1, mean, label = label)
        plt.fill_between(np.arange(T)+1, mean - std, mean+std, alpha = transparency)
        print('alpha=', '%.1f'%alpha, '%.2f'%mean[-1], '('+'%.2f'%std[-1]+')')


'''
label = 'Naive Thompson Sampling'
folder = 'TS_case_study/n-200_T-20_p-'+str(p) + '/'
Regret = []
for i in range(n_repeat):
    regret = np.loadtxt(folder + str(i)+'_regret.txt')
    regret = cumulate(regret)
    Regret.append(regret)


mean = np.mean(Regret, axis = 0)/nt
std = np.std(Regret, axis = 0)/nt
plt.plot(np.arange(T)+1, mean, label = label)
plt.fill_between(np.arange(T)+1, mean - std, mean+std, alpha = transparency)
print('TS:', '%.2f'%mean[-1], '('+'%.2f'%std[-1]+')')
'''

label = 'Random Match'
folder = 'random_match/n-200_T-20_p-'+str(p)+'_alpha-0.0/'
Regret = []
for i in range(n_repeat):
    regret = np.loadtxt(folder + str(i)+'_regret.txt')
    regret = cumulate(regret)
    Regret.append(regret)


mean = np.mean(Regret, axis = 0)/nt
std = np.std(Regret, axis = 0)/nt
plt.plot(np.arange(T)+1, mean, label = label)
plt.fill_between(np.arange(T)+1, mean - std, mean+std, alpha = transparency)
print('Random:', '%.2f'%mean[-1], '('+'%.2f'%std[-1]+')')




plt.xlabel('t')
plt.ylabel('Cumulative regret')
plt.legend()
plt.savefig('UCB_case_study_regret_plot.pdf', bbox_inches='tight')
#plt.show()
plt.close()
